==> react-molecule-stepper-2.0.0.tgz: package/lib/Step/Step.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useRef, forwardRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs/index.js';
import Poly from '@s-ui/react-atom-polymorphic-element';
import { naturalNumber } from '../prop-types.js';
import { BASE_CLASS_STEP } from './settings.js';
import DefaultStep from './DefaultStep.js';
import Children from '../Children.js';
import { useStepsContext } from '../context/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Step = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _cx;

  var as = _ref.as,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? /*#__PURE__*/_jsx(DefaultStep, {}) : _ref$children,
      label = _ref.label,
      current = _ref.current,
      visited = _ref.visited,
      step = _ref.step,
      icon = _ref.icon,
      visitedIcon = _ref.visitedIcon,
      currentIcon = _ref.currentIcon,
      hasConnectorProp = _ref.hasConnector,
      onClick = _ref.onClick;

  var _useStepsContext = useStepsContext(),
      asContext = _useStepsContext.as,
      alignment = _useStepsContext.alignment,
      design = _useStepsContext.design,
      steps = _useStepsContext.steps,
      useContextRef = _useStepsContext.useContextRef,
      useContextUnRef = _useStepsContext.useContextUnRef,
      justifyContent = _useStepsContext.justifyContent,
      iconContext = _useStepsContext.icon,
      visitedIconContext = _useStepsContext.visitedIcon,
      currentIconContext = _useStepsContext.currentIcon,
      hasConnectorContext = _useStepsContext.hasConnector,
      onChange = _useStepsContext.onChange;

  var innerRef = useRef();
  var ref = useMergeRefs(forwardedRef, innerRef, useContextRef);
  var As = as || asContext || 'li';
  var hasConnector = hasConnectorProp === undefined ? hasConnectorContext : hasConnectorProp;
  useContextUnRef(innerRef);

  var onClickHandler = function onClickHandler(event) {
    typeof onClick === 'function' && onClick(event, {
      step: step
    });
    typeof onChange === 'function' && onChange(event, {
      step: step
    });
  };

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(Poly, _extends({
      as: As,
      ref: ref,
      role: "listitem",
      "data-step": "" + step
    }, current && {
      'aria-current': 'step'
    }, {
      className: cx(BASE_CLASS_STEP, [BASE_CLASS_STEP + "--design-" + design, BASE_CLASS_STEP + "--alignment-" + alignment, BASE_CLASS_STEP + "--justifyContent-" + justifyContent], (_cx = {}, _cx[BASE_CLASS_STEP + "--current"] = current, _cx[BASE_CLASS_STEP + "--visited"] = visited, _cx)),
      onClick: onClickHandler,
      children: /*#__PURE__*/_jsx(Children, {
        alignment: alignment,
        design: design,
        label: label,
        step: step,
        steps: steps,
        current: current,
        visited: visited,
        icon: icon || iconContext,
        visitedIcon: visitedIcon || visitedIconContext,
        currentIcon: currentIcon || currentIconContext,
        children: children
      })
    })), hasConnector && steps !== step - 1 && /*#__PURE__*/_jsx(Poly, _extends({
      role: "separator"
    }, steps === step && {
      'aria-hidden': true
    }, {
      as: As,
      className: cx(BASE_CLASS_STEP + "Connector"),
      children: /*#__PURE__*/_jsx("div", {
        className: cx(BASE_CLASS_STEP + "ConnectorLine")
      })
    }))]
  });
});
Step.displayName = 'Step';
export default Step;

==> react-molecule-stepper-2.2.0.tgz: package/lib/Step/Step.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useRef, forwardRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs/index.js';
import Poly from '@s-ui/react-primitive-polymorphic-element';
import Injector from '@s-ui/react-primitive-injector';
import { naturalNumber } from '../prop-types.js';
import { BASE_CLASS_STEP } from './settings.js';
import DefaultStep from './DefaultStep.js';
import { useStepsContext } from '../context/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Step = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _cx;

  var as = _ref.as,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? /*#__PURE__*/_jsx(DefaultStep, {}) : _ref$children,
      label = _ref.label,
      current = _ref.current,
      visited = _ref.visited,
      step = _ref.step,
      icon = _ref.icon,
      visitedIcon = _ref.visitedIcon,
      currentIcon = _ref.currentIcon,
      hasConnectorProp = _ref.hasConnector,
      onClick = _ref.onClick;

  var _useStepsContext = useStepsContext(),
      asContext = _useStepsContext.as,
      alignment = _useStepsContext.alignment,
      design = _useStepsContext.design,
      steps = _useStepsContext.steps,
      useContextRef = _useStepsContext.useContextRef,
      useContextUnRef = _useStepsContext.useContextUnRef,
      justifyContent = _useStepsContext.justifyContent,
      iconContext = _useStepsContext.icon,
      visitedIconContext = _useStepsContext.visitedIcon,
      currentIconContext = _useStepsContext.currentIcon,
      hasConnectorContext = _useStepsContext.hasConnector,
      onChange = _useStepsContext.onChange;

  var innerRef = useRef();
  var ref = useMergeRefs(forwardedRef, innerRef, useContextRef);
  var As = as || asContext || 'li';
  var hasConnector = hasConnectorProp === undefined ? hasConnectorContext : hasConnectorProp;
  useContextUnRef(innerRef);

  var onClickHandler = function onClickHandler(event) {
    typeof onClick === 'function' && onClick(event, {
      step: step
    });
    typeof onChange === 'function' && onChange(event, {
      step: step
    });
  };

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(Poly, _extends({
      as: As,
      ref: ref,
      role: "listitem",
      "data-step": "" + step
    }, current && {
      'aria-current': 'step'
    }, {
      className: cx(BASE_CLASS_STEP, [BASE_CLASS_STEP + "--design-" + design, BASE_CLASS_STEP + "--alignment-" + alignment, BASE_CLASS_STEP + "--justifyContent-" + justifyContent], (_cx = {}, _cx[BASE_CLASS_STEP + "--current"] = current, _cx[BASE_CLASS_STEP + "--visited"] = visited, _cx)),
      onClick: onClickHandler,
      children: /*#__PURE__*/_jsx(Injector, {
        alignment: alignment,
        design: design,
        label: label,
        step: step,
        steps: steps,
        current: current,
        visited: visited,
        icon: icon || iconContext,
        visitedIcon: visitedIcon || visitedIconContext,
        currentIcon: currentIcon || currentIconContext,
        children: children
      })
    })), hasConnector && steps !== step - 1 && /*#__PURE__*/_jsx(Poly, _extends({
      role: "separator"
    }, steps === step && {
      'aria-hidden': true
    }, {
      as: As,
      className: cx(BASE_CLASS_STEP + "Connector"),
      children: /*#__PURE__*/_jsx("div", {
        className: cx(BASE_CLASS_STEP + "ConnectorLine")
      })
    }))]
  });
});
Step.displayName = 'Step';
export default Step;
